==> igniteui-webcomponents-core-3.5.0.tgz: package/esm2015/lib/LabelClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LabelClickEventArgsDescription } from "./LabelClickEventArgsDescription";
/**
 * @hidden
 */
export let LabelClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LabelClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LabelClickEventArgsDescriptionMetadata.a == null) {
                LabelClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LabelClickEventArgsDescriptionMetadata.c(LabelClickEventArgsDescriptionMetadata.a);
            }
            if (a.j(LabelClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(LabelClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("AllowSliceClick", "Boolean");
        }
        static d(a) {
            LabelClickEventArgsDescriptionMetadata.b(a);
            a.aa("LabelClickEventArgs", () => new LabelClickEventArgsDescription());
            a.z("LabelClickEventArgs", LabelClickEventArgsDescriptionMetadata.a);
        }
    }
    LabelClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(LabelClickEventArgsDescriptionMetadata, 'LabelClickEventArgsDescriptionMetadata');
    LabelClickEventArgsDescriptionMetadata.a = null;
    return LabelClickEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/LabelClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { LabelClickEventArgsDescription } from "./LabelClickEventArgsDescription";
/**
 * @hidden
 */
export let LabelClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class LabelClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (LabelClickEventArgsDescriptionMetadata.a == null) {
                LabelClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                LabelClickEventArgsDescriptionMetadata.c(LabelClickEventArgsDescriptionMetadata.a);
            }
            if (a.k(LabelClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(LabelClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
            a.item("AllowSliceClick", "Boolean");
        }
        static d(a) {
            LabelClickEventArgsDescriptionMetadata.b(a);
            a.ac("LabelClickEventArgs", () => new LabelClickEventArgsDescription());
            a.ab("LabelClickEventArgs", LabelClickEventArgsDescriptionMetadata.a);
        }
    }
    LabelClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(LabelClickEventArgsDescriptionMetadata, 'LabelClickEventArgsDescriptionMetadata');
    LabelClickEventArgsDescriptionMetadata.a = null;
    return LabelClickEventArgsDescriptionMetadata;
})();
